@@ -57,11 +57,32 @@ def print_list(func):
             return result
 
         tmp_dict = [
-            {"Name": name, "UUID": item.uuid, "Created": item.created_at}
+            {
+                "Name": name,
+                "UUID": item.uuid,
+                "Created": item.created_at,
+                "Last Modified": item.created_at
+                if not hasattr(item, "last_modified")
+                else item.last_modified,
+            }
             for name, item in result.items()
         ]
 
-        return DataFrame(tmp_dict, columns=["Name", "Created", "UUID"])
+        extra = {}
+        additional_keys = []
+        if func.__name__ == "list_queries":
+            extra = [
+                {"Cached": True if item.cache else ""} for name, item in result.items()
+            ]
+            additional_keys = ["Cached"]
+
+        for index, value in enumerate(extra):
+            tmp_dict[index].update(value)
+
+        return DataFrame(
+            tmp_dict,
+            columns=["Name", "Last Modified", "Created", "UUID"] + additional_keys,
+        )
 
     return wrapper
 
