@@ -283,7 +283,7 @@ class Connection(object):
         )
 
     def file_request(
-        self, path, file_path, data, read_type="rb", method="post", **kwargs
+        self, url, file_path, data, read_type="rb", method="post", **kwargs
     ):
         """Loads a file and formats metadata for specific endpoints and makes server request
 
@@ -297,43 +297,27 @@ class Connection(object):
         Returns:
             Response
         """
-        print("DATA")
-        print(data)
         with open(file_path, read_type) as f:
 
-            # TODO: Make this send params as body instead of headers.
-            if path.find("segmenter/") >= 0:
-                headers = {
-                    "Name": data["name"],
-                    "Type": data["specific_type"],
-                    "Functioninfile": data["functioninfile"],
-                }
-                request = partial(self.request, method, path, data=f, headers=headers)
-
-            # TODO: Make this send params as body instead of headers.
-            elif path.find("transform/") >= 0:
-                headers = {
-                    "Name": data["name"],
-                    "Type": data["type"],
-                    "Functioninfile": data["functioninfile"],
-                    "Subtype": data["subtype"],
-                    "HasCVersion": data["has_c_version"],
-                    "CFileName": data["c_file_name"],
-                }
-                request = partial(self.request, method, path, data=f, headers=headers)
-
-            elif path.find("capture/") >= 0:
+            if url.find("capture/") >= 0:
                 request = partial(
-                    self.request, method, path, files={"file": f}, data=data,
+                    self.request,
+                    method,
+                    url,
+                    files={"file": f},
+                    data=data,
                 )
-
-            elif path.find("featurefile/") >= 0:
+            elif url.find("featurefile/") >= 0:
                 request = partial(
-                    self.request, method, path, files={"data_file": f}, data=data,
+                    self.request,
+                    method,
+                    url,
+                    files={"data_file": f},
+                    data=data,
                 )
             else:
                 request = partial(
-                    self.request, method, path, data=data, files={"file": f}
+                    self.request, method, url, data=data, files={"file": f}
                 )
 
             # call method with previously applied arguments
