@@ -4,13 +4,13 @@ from pandas import DataFrame
 
 class Base(object):
     """
-    Base class for all datamanger objects. 
+    Base class for all datamanger objects.
 
     _data (dict): stores the data response from the server
     _fields (list): list of fields that the model has
     _read_only_fields (list): list of fields that are read only
     _field_map (dict): as some fields are named differently from the server
-        we use a field map dict for backwards compantibility the field map 
+        we use a field map dict for backwards compantibility the field map
         is a dictionary with the following format
         {'client_field_name':'server_field_name'}
 
@@ -27,6 +27,18 @@ class Base(object):
         """
         self._connection = connection
 
+    @property
+    def base_url(self):
+        """Overwrite this property in the subclass for its base url"""
+
+        return ""
+
+    @property
+    def detail_url(self):
+        """Overwrite this property in the subclass for its base url"""
+
+        return ""
+
     @property
     def fields(self):
         return self._fields
@@ -34,8 +46,8 @@ class Base(object):
     @property
     def data(self):
         """
-        Returns the server response data object or 
-        generates the data object from locally stored 
+        Returns the server response data object or
+        generates the data object from locally stored
         properties
         """
         if self._data is None:
@@ -60,10 +72,10 @@ class Base(object):
 
     def initialize_from_dict(self, data):
         """Reads a json dictionary and populates a single object.
-           stores the results in _data as well
+        stores the results in _data as well
 
-            Args:
-                data (dict): server response data object
+         Args:
+             data (dict): server response data object
         """
 
         for field in self._fields:
@@ -73,19 +85,70 @@ class Base(object):
 
         self._data = data
 
+    def refresh(self):
+        """Calls the REST API and populates the local object properties from the server."""
+
+        response = self._connection.request("get", self.detail_url)
+        response_data, err = utility.check_server_response(response)
+        if err is False:
+            self.initialize_from_dict(response_data)
+
+        return response
+
+    def delete(self):
+        """Calls the REST API and populates the local object properties from the server."""
+
+        response = self._connection.request("delete", self.detail_url)
+        response_data, err = utility.check_server_response(response)
+        if err is False:
+            self.initialize_from_dict(response_data)
+
+        return response
+
+    def insert(self, path=None):
+        """Calls the REST API to insert a new object."""
+
+        data = self._to_representation()
+
+        if path:
+            response = self._connection.file_request(self.base_url, path, data, "rb")
+        else:
+            response = self._connection.request("post", self.base_url, data)
+
+        response_data, err = utility.check_server_response(response)
+
+        if err is False:
+            self.initialize_from_dict(response_data)
+
+        return response
+
+    def update(self):
+        """Calls the REST API and updates the object on the server."""
+
+        data = self._to_representation()
+
+        response = self._connection.request("put", self.detail_url, data)
+
+        response_data, err = utility.check_server_response(response)
+
+        if err is False:
+            self.initialize_from_dict(response_data)
+
+        return response
+
 
 class BaseSet(object):
     def __init__(self, connection, initialize_set=True, **kwargs):
         """Initialize a set object to store base objects
 
-            _set (list): a list of objects that are part of the set
-            _objclass (Class): the class obj stored in the set
-            _attr_key (str): a key used to build out the to_dict
+        _set (list): a list of objects that are part of the set
+        _objclass (Class): the class obj stored in the set
+        _attr_key (str): a key used to build out the to_dict
 
-            Args:
-                connection (connection) connection object to server
-                initialze_set (bool) Default is True. If true will build the 
-                 set of objects. 
+        Args:
+            connection (connection) connection object to server
+            initialze_set (bool) Default is True. If true will build the
+             set of objects.
         """
 
         self._connection = connection
@@ -99,7 +162,7 @@ class BaseSet(object):
     @property
     def get_set_url(self):
         """
-          replace this with the url to call to pull down the set objects
+        replace this with the url to call to pull down the set objects
         """
         pass
 
@@ -147,13 +210,13 @@ class BaseSet(object):
     def _new_obj_from_dict(self, data):
         """Creates a new object from the response data from the server.
 
-            Args:
-                data (dict): contains properties of the object
+        Args:
+            data (dict): contains properties of the object
 
-            Returns:
-                obj of type _objclass
+        Returns:
+            obj of type _objclass
 
         """
-        obj = self._objclass(self._connection, self._project)
+        obj = self._objclass(self._connection, project=self._project)
         obj.initialize_from_dict(data)
         return obj
