@@ -6,6 +6,8 @@ from uuid import UUID
 
 
 from pandas import DataFrame
+import json
+
 from numpy import int64
 import urllib
 import logging
@@ -21,7 +23,7 @@ from sensiml.datamanager.deviceconfig import DeviceConfig
 from sensiml.datamanager.platformdescription import PlatformDescription
 from sensiml.datamanager.clientplatformdescription import ClientPlatformDescription
 from sensiml.visualize.knowledgepack_visualize_mixin import VisualizeMixin
-
+from sensiml.datamanager.featurefile import FeatureFile
 
 logger = logging.getLogger(__name__)
 
@@ -44,6 +46,7 @@ class KnowledgePack(VisualizeMixin):
         self._connection = connection
         self._project_uuid = project_uuid
         self._sandbox_uuid = sandbox_uuid
+        self._feature_file_uuid = None
         self._project_name = ""
         self._sandbox_name = ""
         self._configuration_index = ""
@@ -63,6 +66,7 @@ class KnowledgePack(VisualizeMixin):
         self._cost_summary = ""
         self._class_map = ""
         self._device_config = DeviceConfig()
+        self._feature_file_cache = None
 
     @property
     def uuid(self):
@@ -889,6 +893,27 @@ class KnowledgePack(VisualizeMixin):
                 renderer.render(err_msg)
             return err_msg, False
 
+    def get_featurefile(self):
+
+        if self._feature_file_cache is not None:
+            return self._feature_file_cache
+
+        class DummyProject:
+            def __init__(self, uuid):
+                self.uuid = uuid
+
+        ff = FeatureFile(
+            self._connection,
+            project=DummyProject(self.project_uuid),
+            uuid=self._feature_file_uuid,
+        )
+        ff.refresh()
+        res = ff.download_json()
+
+        self._feature_file_cache = DataFrame(json.loads(res.json()))
+
+        return self._feature_file_cache
+
     def initialize_from_dict(self, init_dict):
         self._uuid = init_dict["uuid"]
         self._name = init_dict["name"]
@@ -908,6 +933,7 @@ class KnowledgePack(VisualizeMixin):
             self._neuron_array = json.loads(init_dict["neuron_array"])
             self._project_name = json.loads(init_dict["project_name"])
             self._sandbox_name = json.loads(init_dict["sandbox_name"])
+            self._feature_file_uuid = json.loads(init_dict["feature_file_uuid"])
             self._knowledgepack_summary = json.loads(
                 init_dict.get("knowledgepack_summary", "")
             )
@@ -928,6 +954,7 @@ class KnowledgePack(VisualizeMixin):
             self._neuron_array = init_dict["neuron_array"]
             self._project_name = init_dict["project_name"]
             self._sandbox_name = init_dict["sandbox_name"]
+            self._feature_file_uuid = init_dict["feature_file_uuid"]
             self._knowledgepack_summary = init_dict.get("knowledgepack_summary", None)
             self._knowledgepack_description = init_dict.get(
                 "knowledgepack_description", None
