@@ -67,8 +67,12 @@ class Query(object):
         self._dirty = False
         self._capture_configurations = ""
         self._connection = connection
+        self._summary_statistics = None
         self._project = project
         self._created_at = None
+        self._cache = None
+        self._task_status = None
+        self._last_modified = None
 
     @property
     def uuid(self):
@@ -83,6 +87,15 @@ class Query(object):
         """Name of the query"""
         return self._name
 
+    @property
+    def summary_statistics(self):
+        """Name of the query"""
+        return self._summary_statistics
+
+    @summary_statistics.setter
+    def summary_statistics(self, value):
+        self._summary_statistics = value
+
     @name.setter
     def name(self, value):
         self._dirty = True
@@ -218,6 +231,32 @@ class Query(object):
         else:
             raise ValueError("Value must be a integer")
 
+    @property
+    def task_status(self):
+        return self._task_status
+
+    @task_status.setter
+    def task_status(self, value):
+        self._task_status = value
+
+    @property
+    def last_modified(self):
+        return self._last_modified
+
+    @last_modified.setter
+    def last_modified(self, value):
+        self._last_modified = datetime.datetime.strptime(
+            value[:19], "%Y-%m-%dT%H:%M:%S"
+        )
+
+    @property
+    def cache(self):
+        return self._cache
+
+    @cache.setter
+    def cache(self, value):
+        self._cache = value
+
     def insert(self, renderer=None):
         """Calls the REST API and inserts a new query."""
 
@@ -293,6 +332,30 @@ class Query(object):
         if err is False:
             print(response["result"])
 
+    def cache_query(self, renderer=None):
+        """Caches the current version of the query."""
+        url = "project/{0}/query/{1}/cache/".format(self._project.uuid, self.uuid)
+        request = self._connection.request("post", url)
+        response_data, err = utility.check_server_response(request, renderer=renderer)
+
+        return response_data
+
+    def cache_query_status(self, renderer=None):
+        """Gest the status of the current caching of the querey"""
+        url = "project/{0}/query/{1}/cache/".format(self._project.uuid, self.uuid)
+        request = self._connection.request("get", url)
+        response_data, err = utility.check_server_response(request, renderer=renderer)
+
+        return response_data
+
+    def cache_query_stop(self, renderer=None):
+        """Kills the job for the currently executing query"""
+        url = "project/{0}/query/{1}/cache/".format(self._project.uuid, self.uuid)
+        request = self._connection.request("delete", url)
+        response_data, err = utility.check_server_response(request, renderer=renderer)
+
+        return response_data
+
     def statistics_segments(self, renderer=None):
         """Returns metadata statistics for the query."""
 
@@ -304,36 +367,26 @@ class Query(object):
         else:
             return None
 
-    def statistics(self, renderer=None):
+    def get_statistics_summary(self, renderer=None):
         """Returns metadata statistics for the query."""
-        if self._dirty:
-            self.update(renderer=renderer)
 
-        url = "project/{0}/query/{1}/statistics/".format(self._project.uuid, self.uuid)
-        request = self._connection.request("get", url)
-        response_data, err = utility.check_server_response(request, renderer=renderer)
+        url = "project/{0}/query/{1}/summary-statistics/".format(
+            self._project.uuid, self.uuid
+        )
+        response = self._connection.request("get", url)
+        response_data, err = utility.check_server_response(response, renderer=renderer)
         if err is False:
-            df = DataFrame(response_data)
-            df.drop("Segment Length", axis=1, inplace=True)
-            data = (
-                df.groupby(
-                    ["Capture"] + self.metadata_columns._columns + [self.label_column]
-                )[self.label_column]
-                .size()
-                .unstack(fill_value=0)
-            )
-
-            return data
+            return response_data
         else:
-            return None
+            return response
 
     def plot_statistics(self, renderer=None, **kwargs):
         """Generates a bar plot of the query statistics"""
-        data = self.statistics(renderer=renderer)
+        data = self.statistics_segments(renderer=renderer)
         if data is not None:
-            data.sum().plot(kind="bar", **kwargs)
+            data.groupby(self.label_column).size().plot(kind="bar")
 
-    def data(self):
+    def data(self, partition=0):
         """Calls the REST API for query execution and returns the result.
 
         Note:
@@ -346,9 +399,11 @@ class Query(object):
         if self._dirty:
             self.update()
 
-        url = "project/{0}/query/{1}/data/".format(self._project.uuid, self.uuid)
-        request = self._connection.request("get", url)
-        response_data, err = utility.check_server_response(request)
+        url = "project/{project_uuid}/query/{query_uuid}/data/{partition}".format(
+            project_uuid=self._project.uuid, query_uuid=self.uuid, partition=partition
+        )
+        response = self._connection.request("get", url)
+        response_data, err = utility.check_server_response(response)
         if err is False:
             error_report = None
             if not isinstance(response_data, list):
@@ -360,18 +415,9 @@ class Query(object):
                 except:
                     data = DataFrame(response_data)
 
-            # Post-processing to get numeric index
-            data["sample"] = data.index.astype(int)
-            data = data.set_index("sample")
-            data.index.names = [None]
-            data = data.sort_index(axis=0)
-            cols = data.columns.tolist()
-            if "id" in cols:
-                data = data[["id"] + [c for c in cols if c != "id"]]
-
             return data.sort_index(axis=0), error_report
         else:
-            return None
+            return response
 
     def size(self):
         """Returns the size of the dataframe which would result from the query."""
@@ -404,6 +450,10 @@ class Query(object):
             self.segmenter = response["segmenter_id"]
             self.combine_labels = response["combine_labels"]
             self.capture_configurations = response["capture_configurations"]
+            self.cache = response["cache"]
+            self.task_status = response["task_status"]
+            self.last_modified = response["last_modified"]
+            self.summary_statistics = response["summary_statistics"]
             self._dirty = False
 
     def initialize_from_dict(self, data):
@@ -411,6 +461,7 @@ class Query(object):
         self.uuid = data["uuid"]
         self.name = data["name"]
         self.created_at = data["created_at"]
+        self.last_modified = data["last_modified"]
         self._columns = QueryColumns(data["columns"])
         self._metadata_columns = QueryColumns(data["metadata_columns"])
         self.metadata_filter = data["metadata_filter"]
@@ -418,6 +469,9 @@ class Query(object):
         self.segmenter = data.get("segmenter_id", None)
         self.combine_labels = data.get("combine_labels", None)
         self.capture_configurations = data.get("capture_configurations", "")
+        self.cache = data.get("cache", None)
+        self.task_status = data.get("task_status", None)
+        self.summary_statistics = data.get("summary_statistics")
 
         self._dirty = False
 
