@@ -316,6 +316,7 @@ class Sandbox(object):
         self._features = None
         self._device_config = DeviceConfig()
         self._created_at = None
+        self._last_modified = None
 
     @property
     def uuid(self):
@@ -362,6 +363,16 @@ class Sandbox(object):
                 value[:-6], "%Y-%m-%dT%H:%M:%S.%f"
             )
 
+    @property
+    def last_modified(self):
+        return self._last_modified
+
+    @last_modified.setter
+    def last_modified(self, value):
+        self._last_modified = datetime.datetime.strptime(
+            value[:19], "%Y-%m-%dT%H:%M:%S"
+        )
+
     @property
     def cost_preview(self):
         print(
@@ -703,7 +714,8 @@ class Sandbox(object):
         if err is False:
             self.uuid = data["uuid"]
             self.name = data["name"]
-            self.created = data.get("created_at", None)
+            self.created_at = data.get("created_at", None)
+            self.last_modified = data.get("last_modified", None)
             if not data.get("cache_enabled", True):
                 self.disable_cache()
             self._init_device_config(data)
@@ -728,6 +740,7 @@ class Sandbox(object):
         self.uuid = init_dict["uuid"]
         self.name = init_dict["name"]
         self.created_at = init_dict.get("created_at", None)
+        self.last_modified = init_dict.get("last_modified", None)
 
         if not init_dict.get("cache_enabled", True):
             self.disable_cache()
