@@ -2,9 +2,13 @@ import sqlite3
 import os
 import pandas as pd
 import numpy as np
-from sensiml.datasegments import DataSegments, DataSegment
+from pandas.core.frame import DataFrame
+from sensiml.dclproj.datasegments import DataSegments, DataSegment
 import uuid
 from collections import OrderedDict
+from matplotlib.lines import Line2D
+import matplotlib.pyplot as plt
+from typing import List, Optional, Dict, Tuple
 
 
 class DCLProject:
@@ -19,14 +23,14 @@ class DCLProject:
         return self._verbose
 
     @verbose.setter
-    def verbose(self, value):
+    def verbose(self, value: bool):
         if isinstance(value, bool):
             self._verbose = value
         else:
             print("verbose must be either True or False.")
 
     @property
-    def data_dir(self):
+    def data_dir(self) -> str:
 
         if self._path is None:
             raise Exception("Path is not set!")
@@ -40,7 +44,7 @@ class DCLProject:
 
         self._tables = [x[0] for x in cursorObj.fetchall()]
 
-    def create_connection(self, db_file):
+    def create_connection(self, db_file: str) -> None:
         """create a database connection to the SQLite database
             specified by db_file
         :param db_file: database file
@@ -59,7 +63,7 @@ class DCLProject:
         self._conn = conn
         self._set_table_list()
 
-    def _execute_query(self, query, header=None):
+    def _execute_query(self, query: str, header: str = None) -> DataFrame:
 
         cur = self._conn.cursor()
 
@@ -96,7 +100,7 @@ class DCLProject:
 
         return df
 
-    def _list_table_raw(self, tablename):
+    def _list_table_raw(self, tablename: str) -> DataFrame:
 
         if tablename not in self._tables:
             print("Table is not part of the database.")
@@ -106,7 +110,13 @@ class DCLProject:
 
         return self._execute_query(query)
 
-    def _list_table(self, tablename, fields, fk_fields=None, query_filter=None):
+    def _list_table(
+        self,
+        tablename: str,
+        fields: List[str],
+        fk_fields: Optional[Dict] = None,
+        query_filter: Optional[str] = None,
+    ):
 
         if tablename not in self._tables:
             print("Table is not part of the database.")
@@ -156,7 +166,7 @@ class DCLProject:
 
         return self._execute_query(query_select + query_join + query_where, header)
 
-    def list_captures(self):
+    def list_captures(self) -> DataFrame:
         fields = [
             "uuid",
             "name",
@@ -172,8 +182,9 @@ class DCLProject:
 
         return self._list_table("Capture", fields=fields, fk_fields=fk_fields)
 
-    def list_sessions(self):
+    def list_sessions(self) -> DataFrame:
         fields = [
+            "id",
             "name",
             "parameters",
             "custom",
@@ -187,7 +198,9 @@ class DCLProject:
 
         return self._list_table("Segmenter", fields, fk_fields)
 
-    def list_capture_segments(self, capture=None, session=None):
+    def list_capture_segments(
+        self, capture: Optional[str] = None, session: Optional[str] = None
+    ) -> DataFrame:
 
         query_filter = ""
 
@@ -220,7 +233,20 @@ class DCLProject:
 
         return self._list_table("CaptureLabelValue", fields, fk_fields, query_filter)
 
-    def get_capture_segments(self, capture, session):
+    def get_capture_metadata(self, capture: str) -> DataFrame:
+        "returns a dataframe containing the metadata associated with this capture"
+
+        fields = ["uuid"]
+
+        fk_fields = OrderedDict(
+            [("Capture", "capture"), ("LabelValue", "label_value"), ("Label", "label")]
+        )
+
+        df = self._list_table("CaptureMetadataValue", fields, fk_fields=fk_fields)
+
+        return df[df["capture"] == capture]
+
+    def get_capture_segments(self, capture: str, session: str):
         """
         Returns a DataSegment object of the specified capture and session
 
@@ -234,7 +260,9 @@ class DCLProject:
 
         """
 
-        labels = self.list_capture_segments(capture=capture, session=session)
+        labels = self.list_capture_segments(
+            capture=capture, session=session
+        ).sort_values(by="capture_sample_sequence_start")
 
         # TODO: read wave file if file is .wav
         tmp_df = pd.read_csv(os.path.join(self.data_dir, capture), index_col="sequence")
@@ -243,17 +271,26 @@ class DCLProject:
 
         for index, label in enumerate(
             labels[
-                ["capture_sample_sequence_start", "capture_sample_sequence_end", "uuid"]
+                [
+                    "capture_sample_sequence_start",
+                    "capture_sample_sequence_end",
+                    "uuid",
+                    "label_value",
+                    "capture",
+                ]
             ].values
         ):
-            M[label[2]] = DataSegment(
+            M[index] = DataSegment(
                 tmp_df.loc[label[0] : label[1]],
-                metadata={"segment": index, "capture": capture},
+                segment_index=index,
+                label=label[3],
+                uuid=label[2],
+                capture=label[4],
             )
 
         return M
 
-    def get_capture(self, capture_name):
+    def get_capture(self, capture_name: str) -> DataFrame:
         """
         Returns the capture as a dataframe
 
@@ -269,81 +306,176 @@ class DCLProject:
 
         return tmp_df
 
-    def plot_segment_labels(
-        self,
-        capture_name,
-        session,
-        recognized=None,
-        class_map=None,
-        groups=None,
-        figsize=(24, 6),
-        style="x",
-        ms=2,
-    ):
+    def get_captures(self, capture_names: Optional[List[str]] = None) -> DataFrame:
         """
-        Creates a plot of the labels and raw signal data for a capture and session.
-        Will also overlay the results of recognize signal for the capture file and model.
-
+        Returns the capture as a single dataframe
 
         Args:
-            capture_name (str): name of capture
-            session (str):  name of session where the labels are
-            recognized (Dataframe): results from recognize signal on this capture
-            class_map (dict): The class map describing how to map the labels to
-             integer values
-            groups (dict): a dict of key value pairs where the key is the original
-              label the value is the label it was should be renamed to
+            capture_names (List[str]): name of captures to return, if None returns all captures
+
+        """
+        if capture_names is None:
+            capture_names = os.listdir(self.datadir)
+
+        return pd.concat(
+            map(
+                pd.read_csv,
+                [os.path.join(self.datadir, capture) for capture in capture_names],
+            )
+        ).reset_index(drop=True)
+
+    def plot_segment_labels(
+        self,
+        capture_names: List[str],
+        session: str,
+        columns: Optional[List[str]] = None,
+        transforms: Optional[List[Dict]] = None,
+        figsize: Tuple = (30, 8),
+        ylim: Optional[Tuple] = None,
+    ) -> None:
+        """
+        Creates a plot of the labels and raw signal data for a session and one or more capture files.
+
+        Args:
+            capture_names (List[str]): List if captures to plot
+            session (str):  name of session to pull the labels from
+            columns (list): a list of columns to plot from the data
+             label the value is the label it was should be renamed to
+            transforms: additional fucntions to apply prior to plotting the data
+
+
+        example of a single transform::
+
+        ```
+            def sum_columns(x):
+                return x[['Column1', 'Column2']].sum()
+
+            func = {'name':'sum','func':sum_columns, 'type':'transform'}
+
+            dcl.plot_segment_labels(captures, session_name, columns=['sum], transforms=[func])
+        ```
+
+        example of multiple transforms
+        transforms will be executed in order
+
+        ```
+
+            def sum_columns(x):
+                return x[['Column1', 'Column2']].sum()
+
+            def remove_offset(x):
+                x['Column1']-=100
+                x['Column2']-=200
+                return x
+
+            func2 = {'name':'filter','func':remove_offset, "type":'filter', "columns":['Column1', 'Column2']}
+            func1 = {'name':'sum','func':sum_columns, "type":'transform'}
+
+
+            dcl.plot_segment_labels(captures, session_name, columns=['Column1', 'Column2', 'sum'], transforms=[func1, func2])
+
+
         """
 
-        segments = self.list_capture_segments(capture_name, session)
-        capture = self.get_capture(capture_name)
+        sessions = self.list_sessions()
+        session_id = sessions[sessions.name == session].id.values[0]
+        clv = self._list_table_raw("CaptureLabelValue")
+        label_value_ids = clv[clv.segmenter == session_id].label_value.unique()
+        lv = self._list_table_raw("LabelValue")
+        labels = sorted(lv[lv.id.isin(label_value_ids)].value.values.tolist())
+        class_map = {label: index for index, label in enumerate(labels)}
 
-        if groups:
-            segments["label_value"] = segments["label_value"].apply(
-                lambda x: x if x not in groups else groups[x]
-            )
+        M = []
+        current_start = 0
 
-        if class_map is None:
-            class_map = {
-                label: index
-                for index, label in enumerate(segments.label_value.unique())
+        plt.figure(figsize=figsize)
+        currentAxis = plt.gca()
+
+        if isinstance(capture_names, str):
+            capture_names = [capture_names]
+
+        for capture_name in capture_names:
+            segments = self.list_capture_segments(capture_name, session)
+            capture = self.get_capture(capture_name)
+            M.append(capture)
+
+            capture.describe().loc["max"].max()
+
+            cmap = plt.cm.rainbow
+
+            labels = list(class_map.keys())
+
+            delta = 1 / len(labels)
+            label_float = np.arange(0, 1, delta)
+            label_float[-1] = 1.0
+
+            label_colors = {
+                labels[index]: cmap(x) for index, x in enumerate(label_float)
             }
+            label_legend = [
+                Line2D([0], [0], color=cmap(x), lw=4) for x in label_float
+            ] + [Line2D([0], [0], color="white", lw=4)]
 
-        M = {k: np.zeros(len(capture)) - 1 for k in segments.label_value.unique()}
-        M["Unknown"] = np.zeros(len(capture))
+            for _, seg in segments.iterrows():
+                y_origin = (
+                    capture.describe().loc["min"].min() if ylim is None else ylim[0]
+                )
+                x_origin = seg["capture_sample_sequence_start"] + current_start
+                x_final = (
+                    seg["capture_sample_sequence_end"]
+                    - seg["capture_sample_sequence_start"]
+                )
+                y_final = (
+                    capture.describe().loc["max"].max() - y_origin
+                    if ylim is None
+                    else ylim[1] - ylim[0]
+                )
 
-        for index, seg in segments.iterrows():
-            M[seg["label_value"]][
-                seg["capture_sample_sequence_start"] : seg[
-                    "capture_sample_sequence_end"
-                ]
-            ] = class_map[seg["label_value"]]
-            M["Unknown"][
-                seg["capture_sample_sequence_start"] : seg[
-                    "capture_sample_sequence_end"
-                ]
-            ] = -1
+                currentAxis.add_artist(
+                    plt.Rectangle(
+                        (x_origin, y_origin),
+                        x_final,
+                        y_final,
+                        alpha=0.2,
+                        color=label_colors[seg["label_value"]],
+                    )
+                )
 
-        ytick_values = [0] + sorted(list(class_map.values()))
-        r_class_map = {v: k for k, v in class_map.items()}
-        r_class_map[0] = "Unknown"
-        ytick_labels = [r_class_map[x] for x in ytick_values]
+            currentAxis.legend(label_legend, labels + [""])
 
-        ax = pd.DataFrame(M).plot(
-            ylim=(-0.5, len(M) + 1),
+            currentAxis.text(
+                current_start,
+                0 if ylim is None else ylim[0],
+                capture_name,
+                style="italic",
+                rotation=90,
+                # bbox={"facecolor": "grey", "alpha": 0.5, "pad": 10},
+            )
+
+            current_start += capture.shape[0]
+
+        capture = pd.concat(M)
+
+        if transforms is not None:
+            for func in transforms:
+                if func["type"] == "transform":
+                    capture[func["name"]] = capture.apply(
+                        lambda x: func["func"](x), axis=func.get("axis", 1)
+                    )
+
+                if func["type"] == "filter":
+                    capture[func["columns"]] = capture.apply(
+                        lambda x: func["func"](x), axis=func.get("axis", 1)
+                    )
+
+        if columns is None:
+            columns = capture.columns
+
+        capture[columns].reset_index(drop=True).plot(
             figsize=figsize,
-            style=style,
-            ms=ms,
-            yticks=ytick_values,
+            ax=currentAxis,
+            title="session: '{session}'".format(capture=capture_name, session=session),
+            ylim=ylim,
         )
-        ax.set_yticklabels(ytick_labels)
 
-        if recognized is not None:
-            recognized["classification_step"] = (
-                recognized["SegmentStart"] + recognized["SegmentLength"] / 2
-            )
-            recognized.plot(
-                y="Classification", x="classification_step", ax=ax, style="-x"
-            )
-
-        capture.reset_index(drop=True).plot(figsize=figsize)
+        return capture.reset_index(drop=True)
