@@ -201,11 +201,9 @@ class AutoSenseWidget(BaseWidget):
             ]
 
         if seed_choice == "Custom Feature Generatorset":
-            subtype_list = self.custom_feature_generator.get_subtype_list()
-            self._dsk.pipeline.add_feature_generator(
-                [{"subtype_call": str(x)} for x in subtype_list],
-                function_defaults={"columns": self._dsk.pipeline.data_columns},
-            )
+            params[
+                "generatorset"
+            ] = self.custom_feature_generator.get_fature_generator()
 
         print("Auto Sense Params", params)
         self._dsk.pipeline.describe()
@@ -389,7 +387,9 @@ class AutoSenseWidget(BaseWidget):
         )
 
         self._w_segment = widgets.Dropdown(
-            description="Segmenter", options=["", "Windowing"], style=description_style,
+            description="Segmenter",
+            options=["", "Windowing"],
+            style=description_style,
         )
 
         self._w_window_size = widgets.BoundedIntText(
