@@ -609,7 +609,9 @@ class DownloadWidgetVersion2(BaseWidget):
             layout=Layout(width="90%"),
         )
         self._widget_debug = Dropdown(
-            description="Debug", options=[False, True], style=description_style,
+            description="Debug",
+            options=[False, True],
+            style=description_style,
         )
         self._widget_debug_level = Dropdown(
             description="Debug Level", options=[1, 2, 3], style=description_style
