@@ -38,7 +38,12 @@ class FeatureGeneratorWidget(BaseWidget):
         for index, subtype in enumerate(self._w_subtype):
             subtype.children[0].value = False
 
+    def get_subtype_list(self):
+        subtype_list = get_active_subtypes(self._w_grid)
+        return subtype_list
+
     def get_fature_generator(self):
+
         subtype_list = get_active_subtypes(self._w_grid)
 
         feature_generators = self._dsk.pipeline.add_feature_generator(
