@@ -407,8 +407,8 @@ class QueryWidget:
             seg = self._dsk.list_segmenters()
 
             self._sensor_columns_mselector.value = qdict["sensor_columns"]
-            self._capture_configurations_mselector.value = self.get_name_capture_configurations(
-                qdict["capture_configurations"]
+            self._capture_configurations_mselector.value = (
+                self.get_name_capture_configurations(qdict["capture_configurations"])
             )
             self._metadta_items_mselect.value = qdict["metadata_columns"]
             self._label_column_select.value = qdict["label_column"]
